@@ -1,9 +1,11 @@
 require 'set'
+require 'active_record'
 
 module Joiner
   class AssociationNotFound < StandardError
   end
 end
 
+require 'joiner/join_dependency'
 require 'joiner/joins'
 require 'joiner/path'
